==> haskell-shelly-1.10.0-6-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-shelly.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 shelly
version:              1.10.0
visibility:           public
id:                   shelly-1.10.0-kkqYe5L68MAW4F2OcKna4
key:                  shelly-1.10.0-kkqYe5L68MAW4F2OcKna4
license:              BSD-3-Clause
maintainer:           Greg Weber <greg@gregweber.info>, Andreas Abel
author:               Greg Weber, Petr Rockai
homepage:             https://github.com/yesodweb/Shelly.hs
synopsis:             shell-like (systems) programming in Haskell
description:
    Shelly provides convenient systems programming in Haskell,
    similar in spirit to POSIX shells. Shelly:

    * is aimed at convenience and getting things done rather than
    being a demonstration of elegance,

    * has detailed and useful error messages,

    * maintains its own environment, making it thread-safe.

    Shelly is originally forked from the Shellish package.

    See the shelly-extra package for additional functionality.

    An overview is available in the README: <https://github.com/yesodweb/Shelly.hs/blob/master/README.md>

category:             Development
abi:                  5fd27fafe1a9f8361ef5b69f863d62d4
exposed:              True
exposed-modules:      Shelly Shelly.Lifted Shelly.Pipe Shelly.Unix
hidden-modules:       Shelly.Base Shelly.Find Shelly.Directory
import-dirs:          /usr/lib/ghc-9.0.2/site-local/shelly-1.10.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/shelly-1.10.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-shelly
hs-libraries:         HSshelly-1.10.0-kkqYe5L68MAW4F2OcKna4
depends:
    async-2.2.4-6KBqZB2hivBDO34h1S6aOW base-4.15.1.0
    bytestring-0.10.12.1 containers-0.6.4.1 directory-1.3.6.2
    enclosed-exceptions-1.0.3-GlIh7g226pf6Zq4GnvRKak exceptions-0.10.4
    filepath-1.4.2.1 lifted-async-0.10.2.2-HBnun5S64yG2HoqE8fK0t3
    lifted-base-0.2.3.12-LWSQzio2eh3UpCDIj9fuI
    monad-control-1.0.3.1-1UdV54K1izzABtSLaOUgnj mtl-2.2.2
    process-1.6.13.2 text-1.2.5.0 time-1.9.3 transformers-0.5.6.2
    transformers-base-0.4.6-DnLUIX7W73LJlURzsbBten
    unix-compat-0.5.4-FTzJDG4psNuKZpJlJ2Zo5B

haddock-interfaces:   /usr/share/doc/haskell-shelly/html/shelly.haddock
haddock-html:         /usr/share/doc/haskell-shelly/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-shelly-1.10.0-10-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-shelly.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 shelly
version:              1.10.0
visibility:           public
id:                   shelly-1.10.0-LaIfyVpeiYh8CQv49SLMNw
key:                  shelly-1.10.0-LaIfyVpeiYh8CQv49SLMNw
license:              BSD-3-Clause
maintainer:           Greg Weber <greg@gregweber.info>, Andreas Abel
author:               Greg Weber, Petr Rockai
homepage:             https://github.com/yesodweb/Shelly.hs
synopsis:             shell-like (systems) programming in Haskell
description:
    Shelly provides convenient systems programming in Haskell,
    similar in spirit to POSIX shells. Shelly:

    * is aimed at convenience and getting things done rather than
    being a demonstration of elegance,

    * has detailed and useful error messages,

    * maintains its own environment, making it thread-safe.

    Shelly is originally forked from the Shellish package.

    See the shelly-extra package for additional functionality.

    An overview is available in the README: <https://github.com/yesodweb/Shelly.hs/blob/master/README.md>

category:             Development
abi:                  8091b0148c834daf87a7cec2319539fb
exposed:              True
exposed-modules:      Shelly Shelly.Lifted Shelly.Pipe Shelly.Unix
hidden-modules:       Shelly.Base Shelly.Find Shelly.Directory
import-dirs:          /usr/lib/ghc-9.0.2/site-local/shelly-1.10.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/shelly-1.10.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-shelly
hs-libraries:         HSshelly-1.10.0-LaIfyVpeiYh8CQv49SLMNw
depends:
    async-2.2.4-2ufaJCQRySkEO7WXEoMHRn base-4.15.1.0
    bytestring-0.10.12.1 containers-0.6.4.1 directory-1.3.6.2
    enclosed-exceptions-1.0.3-7P7NBOXvfVMBXtNVJPHHPT exceptions-0.10.4
    filepath-1.4.2.1 lifted-async-0.10.2.2-D2aLCL6I3Zu3086HAVBx1t
    lifted-base-0.2.3.12-LN4JOfUDkP28b348ryiIbN
    monad-control-1.0.3.1-AK8cMRBJFcdAag5TRh4yqA mtl-2.2.2
    process-1.6.13.2 text-1.2.5.0 time-1.9.3 transformers-0.5.6.2
    transformers-base-0.4.6-4OrcBiGYfPtDiwIqVfT3jr
    unix-compat-0.5.4-FTzJDG4psNuKZpJlJ2Zo5B

haddock-interfaces:   /usr/share/doc/haskell-shelly/html/shelly.haddock
haddock-html:         /usr/share/doc/haskell-shelly/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
